==> nextcloud-app-mail-5.1.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lb.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Wichteg",
    "Work" : "Aarbecht",
    "Personal" : "Perséinlech",
    "Mail" : "Mail",
    "Save" : "Späicheren",
    "Connect" : "Verbannen",
    "Name" : "Numm",
    "Password" : "Passwuert",
    "None" : "Keng",
    "Go back" : "Zeréckgoen",
    "Cancel" : "Ofbriechen",
    "Accounts" : "Accounts",
    "General" : "Allgemeng",
    "Delete" : "Läschen",
    "Search" : "Search",
    "Send" : "Schécken",
    "Refresh" : "Opfrëschen",
    "Select account" : "Account auswielen",
    "Choose" : "Auswielen",
    "Confirm" : "Konfirméieren",
    "Favorite" : "Favorit",
    "Edit tags" : "Tags editéieren",
    "Back" : "Zeréck",
    "Description" : "Beschreiwung",
    "Create" : "Erstellen",
    "Select" : "Select",
    "Comment" : "Kommentar",
    "Remove" : "Läschen",
    "Other" : "Aner",
    "Translate" : "Iwwersetzen",
    "Unnamed" : "ouni Numm",
    "Move" : "Verschieben",
    "Remove account" : "De Kont läschen",
    "Quota" : "Quota",
    "Folder name" : "Dossiers Numm:",
    "Saving" : "Speicheren...",
    "Rename" : "Ëmbenennen",
    "Reply" : "Äntwerten",
    "Add" : "Derbäimaachen",
    "Close" : "Zoumaachen",
    "Date" : "Date",
    "Tags" : "Tags",
    "Custom" : "Individualiséier",
    "Reset" : "Zeréck setzen",
    "Client ID" : "Client ID",
    "User" : "User",
    "Host" : "Host",
    "Port" : "Port",
    "All" : "All",
    "Favorites" : "Favoriten",
    "Actions" : "Aktiounen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.3.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lb.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Wichteg",
    "Work" : "Aarbecht",
    "Personal" : "Perséinlech",
    "Mail" : "Mail",
    "Save" : "Späicheren",
    "Connect" : "Verbannen",
    "Name" : "Numm",
    "Password" : "Passwuert",
    "None" : "Keng",
    "Go back" : "Zeréckgoen",
    "Cancel" : "Ofbriechen",
    "Accounts" : "Accounts",
    "General" : "Allgemeng",
    "Delete" : "Läschen",
    "Search" : "Search",
    "Send" : "Schécken",
    "Refresh" : "Opfrëschen",
    "Ok" : "OK",
    "Select account" : "Account auswielen",
    "Choose" : "Auswielen",
    "Confirm" : "Konfirméieren",
    "Favorite" : "Favorit",
    "Edit tags" : "Tags editéieren",
    "Back" : "Zeréck",
    "Attendees" : "Participanten",
    "Description" : "Beschreiwung",
    "Create" : "Erstellen",
    "Select" : "Select",
    "Comment" : "Kommentar",
    "Remove" : "Läschen",
    "Today" : "Haut",
    "Other" : "Aner",
    "Translate" : "Iwwersetzen",
    "Unnamed" : "ouni Numm",
    "Move" : "Verschieben",
    "Remove account" : "De Kont läschen",
    "Folder name" : "Dossiers Numm:",
    "Saving" : "Speicheren...",
    "Rename" : "Ëmbenennen",
    "Reply" : "Äntwerten",
    "Add" : "Derbäimaachen",
    "Close" : "Zoumaachen",
    "Date" : "Date",
    "Tags" : "Tags",
    "Custom" : "Individualiséier",
    "Reset" : "Zeréck setzen",
    "Client ID" : "Client ID",
    "User" : "User",
    "Host" : "Host",
    "Port" : "Port",
    "Group" : "Grupp",
    "Shared" : "Gedeelt",
    "All" : "All",
    "Favorites" : "Favoriten"
},
"nplurals=2; plural=(n != 1);");
